# frozen_string_literal: true

# Provide common settings for the service.
#
# All of these settings can be accessed via `Application[:settings]`,
# or using IoC injection, as:
#
# @example dry-auto_inject
#   class Foo
#     include Import[:settings]
#     def call
#       puts "Running in pod #{settings.pod_name}"
#     end
#   end
#
# Each of these settings can be provided as an environment variable;
# or in a `.env` file; or in a `.env.development` file, where the
# value of `$RACK_ENV` is used as the suffix.  Each of the settings
# becomes an attribute on the settings object.
Application.boot(:settings, from: :system) do
  init do
    require 'cht-lib-fabric/dry_types'
  end

  settings do
    key :redis_workers_service_host, ::Platform::DryTypes::Coercible::String.default('localhost')
    key :redis_workers_service_port, ::Platform::DryTypes::Coercible::Integer.default(6379)
    # Any non-empty value enables debugging
    key :redis_debug, ::Platform::DryTypes::Coercible::String.default('')

    key :mysql_config_file, ::Platform::DryTypes::Coercible::String.default('./database.yml.erb')

    # Kafka
    key :kafka_host, ::Platform::DryTypes::Coercible::String.default('localhost:9092')
    key :kafka_topic_prefix, ::Platform::DryTypes::Coercible::String.default('')

    # Wiring to reach the token-provider JWKS endpoint and validate tokens
    key :jwks_uri, ::Platform::DryTypes::Coercible::String.default('')
    key :pod_name, ::Platform::DryTypes::Coercible::String.default('__pod__')
    # If non-empty, allow the dev RSA key
    key :developer_jwt_signing, ::Platform::DryTypes::Coercible::String.default('')

    # Wiring to reach Rollbar
    key :rollbar_token, ::Platform::DryTypes::Coercible::String.default('')
    key :rollbar_env, ::Platform::DryTypes::Coercible::String.default('')
    key :k8s_pod, ::Platform::DryTypes::Coercible::String.default('')
    key :k8s_ns, ::Platform::DryTypes::Coercible::String.default('')

    # Wavefront integration
    key :wf_host, ::Platform::DryTypes::Coercible::String.default('')
    key :wf_port, ::Platform::DryTypes::Coercible::Integer.default(2181)
    key :zipkin_port, ::Platform::DryTypes::Coercible::Integer.default(9411)
    key :zipkin_url, ::Platform::DryTypes::Coercible::String.default('')

    key :tenant_uri, ::Platform::DryTypes::Coercible::String.default('http://tenant.tenant/graphql')
    key :role_management_uri, ::Platform::DryTypes::Coercible::String.default('http://role-management.role_management/graphql')
    key :authorization_uri, ::Platform::DryTypes::Coercible::String.default('http://authorization.authorization/graphql')
    key :service_accounts_config_file, ::Platform::DryTypes::Coercible::String.default('./service_integration_accounts.yml')
  end
end
